==> zio-aws-chimesdkmediapipelines_2.13-6.20.115.2-sources.jar: zio/aws/chimesdkmediapipelines/model/SelectedVideoStreams.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.ZIO
import zio.aws.chimesdkmediapipelines.model.primitives.{
  ExternalUserIdType,
  GuidString
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SelectedVideoStreams(
    attendeeIds: Optional[Iterable[GuidString]] = Optional.Absent,
    externalUserIds: Optional[Iterable[ExternalUserIdType]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams = {
    import SelectedVideoStreams.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
      .builder()
      .optionallyWith(
        attendeeIds.map(value =>
          value.map { item =>
            GuidString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.attendeeIds)
      .optionallyWith(
        externalUserIds.map(value =>
          value.map { item =>
            ExternalUserIdType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.externalUserIds)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams
      .wrap(buildAwsValue())
}
object SelectedVideoStreams {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams =
      zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams(
        attendeeIds.map(value => value),
        externalUserIds.map(value => value)
      )
    def attendeeIds: Optional[List[GuidString]]
    def externalUserIds: Optional[List[ExternalUserIdType]]
    def getAttendeeIds: ZIO[Any, AwsError, List[GuidString]] =
      AwsError.unwrapOptionField("attendeeIds", attendeeIds)
    def getExternalUserIds: ZIO[Any, AwsError, List[ExternalUserIdType]] =
      AwsError.unwrapOptionField("externalUserIds", externalUserIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
  ) extends zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams.ReadOnly {
    override val attendeeIds: Optional[List[GuidString]] = zio.aws.core.internal
      .optionalFromNullable(impl.attendeeIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.chimesdkmediapipelines.model.primitives.GuidString(item)
        }.toList
      )
    override val externalUserIds: Optional[List[ExternalUserIdType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.externalUserIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.chimesdkmediapipelines.model.primitives
              .ExternalUserIdType(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
  ): zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmediapipelines_3-5.19.26.1-sources.jar: zio/aws/chimesdkmediapipelines/model/SelectedVideoStreams.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.ZIO
import zio.aws.chimesdkmediapipelines.model.primitives.{
  ExternalUserIdType,
  GuidString
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SelectedVideoStreams(
    attendeeIds: Optional[Iterable[GuidString]] = Optional.Absent,
    externalUserIds: Optional[Iterable[ExternalUserIdType]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams = {
    import SelectedVideoStreams.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
      .builder()
      .optionallyWith(
        attendeeIds.map(value =>
          value.map { item =>
            GuidString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.attendeeIds)
      .optionallyWith(
        externalUserIds.map(value =>
          value.map { item =>
            ExternalUserIdType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.externalUserIds)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams
      .wrap(buildAwsValue())
}
object SelectedVideoStreams {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams =
      zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams(
        attendeeIds.map(value => value),
        externalUserIds.map(value => value)
      )
    def attendeeIds: Optional[List[GuidString]]
    def externalUserIds: Optional[List[ExternalUserIdType]]
    def getAttendeeIds: ZIO[Any, AwsError, List[GuidString]] =
      AwsError.unwrapOptionField("attendeeIds", attendeeIds)
    def getExternalUserIds: ZIO[Any, AwsError, List[ExternalUserIdType]] =
      AwsError.unwrapOptionField("externalUserIds", externalUserIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
  ) extends zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams.ReadOnly {
    override val attendeeIds: Optional[List[GuidString]] = zio.aws.core.internal
      .optionalFromNullable(impl.attendeeIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.chimesdkmediapipelines.model.primitives.GuidString(item)
        }.toList
      )
    override val externalUserIds: Optional[List[ExternalUserIdType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.externalUserIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.chimesdkmediapipelines.model.primitives
              .ExternalUserIdType(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.SelectedVideoStreams
  ): zio.aws.chimesdkmediapipelines.model.SelectedVideoStreams.ReadOnly =
    new Wrapper(impl)
}
